#!/bin/sh -efu

[ "$LONG_OPTION" = 'change-files' ] || exit

: ${PESIGN:=pesign -f}
: ${PECERT:?}

tmp="$(mktemp -t)"
trap 'rc=$?; rm -f -- "$tmp"; exit $rc' EXIT
trap 'exit 143' HUP INT QUIT TERM

whitelisted() {
	case "$1" in
		./usr/lib64/efi/mmx64.efi|./usr/lib64/efi/mmia32.efi)
			return 0 ;;
		./usr/lib64/efi/fbx64.efi|./usr/lib64/efi/fbia32.efi)
			return 0 ;;
		./usr/lib64/efi/grubx64.efi|./usr/lib64/efi/grubia32.efi)
			return 0 ;;
		./usr/lib64/efi/fwupdx64.efi)
			return 0 ;;
		./boot/vmlinuz-*)
			return 0 ;;
		*)
			return 1 ;;
	esac
}

cd "$RPM_BUILD_ROOT"
find -type f -writable \( -path './boot/vmlinuz-*' -o -path './usr/lib64/efi/*.efi' \) |
while read pefile; do
	whitelisted "$pefile" || continue
	case "$pefile" in
		*/*.efi)
			objdump -s -j .sbat "$pefile" 2>/dev/null |
				grep -qx '^Contents of section \.sbat:$' ||
					continue ;;
	esac
	objdump -rw "$pefile" |
		grep -qx '[^:]*:[[:blank:]]*file format pei-\(x86-64\|i386\)[[:blank:]]*' ||
			continue
	> "$tmp"
	$PESIGN -s ${PETOKEN:+-t "$PETOKEN"} -c "$PECERT" -i "$pefile" -o "$tmp"
	cat "$tmp" > "$pefile"
done

[ -s "$tmp" ]
