#!/bin/sh -efu

[ "$LONG_OPTION" = 'change-spec-whole' ] || exit

tmp="$(mktemp -t)"
trap 'rc=$?; rm -rf -- "$tmp"; exit $rc' EXIT
trap 'exit 143' HUP INT QUIT TERM

cat > "$tmp" <<'EOF'
%global __find_scriptlet_requires %nil
%global __find_debuginfo_files %nil
EOF
cat >> "$tmp"

b_n="$(sed '/^Name:[[:space:]]*/!d;s///;q' "$tmp")"
b_v="$(sed '/^Version:[[:space:]]*/!d;s///;q' "$tmp")"
b_r="$(sed '/^Release:[[:space:]]*/!d;s///;q' "$tmp")"
sourcerpm="$(sed '/^#sourcerpm:[[:space:]]*/I!d;s///;q' "$tmp")"
s_r="${sourcerpm##*-}"
s_r="${s_r%.src.rpm}"
s_v="${sourcerpm%-*}"
s_n="${s_v%-*}"
s_v="${s_v##*-}"

if [ "$s_n-$s_v-$s_r" = "$b_n-$b_v-$b_r" ]; then
	cat "$tmp"
	exit 0
fi

. shell-quote

quote_sed_regexp_variable qs_n "$s_n"
quote_sed_regexp_variable qs_v "$s_v"
quote_sed_regexp_variable qs_r "$s_r"
quote_sed_regexp_variable qb_n "$b_n"
quote_sed_regexp_variable qb_v "$b_v"
quote_sed_regexp_variable qb_r "$b_r"

sed -e "
1,/^%description$/{
/^Name:.*/ s//Name: $qs_n/
/^Version:.*/ s//Version: $qs_v/
/^Release:.*/ s//Release: $qs_r/
/^Summary:/,/^\\(Conflicts\\|Obsoletes\\|Provides\\|Requires\\):/{
/^\\(Conflicts\\|Obsoletes\\|Provides\\|Requires\\):/ i\\
%package -n $qb_n\\
Summary: %summary\\
Group: %group\\
Version: $qb_v\\
Release: $qb_r\\
AutoReqProv: no
}
}
/^%description$/ a %description -n $qb_n
s/^%\\(trigger[^ ]*\\|pre\\|post\\|preun\\|postun\\|verifyscript\\) /&-n $qb_n /
s/^%\\(files\\|pre\\|post\\|preun\\|postun\\|verifyscript\\)$/& -n $qb_n/
" < "$tmp"
